import { clsx } from 'clsx';
//import { twMerge } from 'tailwind-merge';
import plugin from 'tailwindcss/plugin';
export type { PluginCreator } from 'tailwindcss/types/config';

export const tw = (...args: Parameters<typeof clsx>) => clsx(...args);

export const basePlugin = plugin(
	({ addUtilities, matchUtilities, theme }) => {
		matchUtilities(
			{
				font: (value) => ({
					tabSize: value,
				}),
			},
			{
				values: theme('fontStretch'),
			},
		);

		addUtilities({
			'.linejoin-round': {
				'stroke-linejoin': 'round',
			},
			'.linecap-round': {
				'stroke-linecap': 'round',
			},
		});
	},
	{
		theme: {
			extend: {
				colors: {
					'current': 'currentcolor',
					'inherit': 'inherit',
					'transparent': 'transparent',
				},
				fontFamily: {
					inherit: ['inherit'],
				},
				fontStretch: {
					'condensed': 'condensed',
					'semi-condensed': 'semi-condensed',
					'expanded': 'expanded',
					'semi-expanded': 'semi-expanded',
					'inherit': 'inherit',
				},
				borderRadius: {
					inherit: 'inherit',
				},
				minWidth: {
					6: '1.5rem',
					10: '2.5rem',
					12: '3rem',
					16: '4rem',
					48: '12rem',
					64: '16rem',
				},
				minHeight: {
					6: '1.5rem',
					10: '2.5rem',
					12: '3rem',
					16: '4rem',
					32: '8rem',
					64: '16rem',
				},
				strokeWidth: {
					3: '3',
				},
			},
		},
	},
);
